CMake Python Distributions
==========================

`CMake <https://cmake.org>`_ is used to control the software compilation
process using simple platform and compiler independent configuration files,
and generate native makefiles and workspaces that can be used in the
compiler environment of your choice.

The suite of CMake tools were created by Kitware in response to the need
for a powerful, cross-platform build environment for open-source projects
such as `ITK <https://itk.org>`_ and `VTK <https://vtk.org>`_.

The CMake python wheels provide `CMake 4.4.0 <https://cmake.org/cmake/help/v4.4/index.html>`_.

.. toctree::
   :maxdepth: 2
   :caption: User guide

   installation
   usage
   building
   build_system
   contributing
   authors
   history

.. toctree::
   :maxdepth: 2
   :caption: For maintainers

   update_cmake_version
   make_a_release


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Resources
=========

This project was created by Jean-Christophe Fillion-Robin from Kitware Inc. and
is maintained by the `scikit-build <https://github.com/scikit-build>`_ community.
It is covered by the `Apache License, Version 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`_.

CMake is distributed under the OSI-approved BSD 3-clause License.
For more information about CMake, visit https://cmake.org

* Documentation: https://cmake-python-distributions.readthedocs.io/en/latest/
* Source code: https://github.com/scikit-build/cmake-python-distributions
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build
